#include <iostream>
#include <algorithm>
#include <vector>
#include <limits.h>
#include <random>
#include <chrono>
using namespace std;
typedef long long ll;

pair<ll, ll> brutus(const vector<ll>& A, const vector<ll>& B, int l, int r, ll x0, ll y0)
{
	ll x = x0;
	ll y = y0;
	for (int i = l; i <= r; i++)
	{
		x = 2 * A[i] - x;
		y = 2 * B[i] - y;
	}
	return { x,y };
}

ll compute_coordinate(const vector<ll>& prefix_even, const vector<ll>& prefix_odd, int l, int r, ll coord)
{
	ll to_add = 0, to_sub = 0;
	if (r % 2 == 1)
	{
		to_add = l > 0 ? prefix_odd[r] - prefix_odd[l-1] : prefix_odd[r];
		to_sub = l > 0 ? prefix_even[r] - prefix_even[l - 1] : prefix_even[r];
	}
	else
	{
		to_sub = l > 0 ? prefix_odd[r] - prefix_odd[l - 1] : prefix_odd[r];
		to_add = l > 0 ? prefix_even[r] - prefix_even[l - 1] : prefix_even[r];
	}
	if ((r - l + 1) % 2 == 0)
	{
		return 2*(to_add - to_sub) + coord;
	}
	else
		return 2*(to_add - to_sub) - coord;
}

vector<ll> make_prefixes(const vector<ll>& values, int start)
{
	vector<ll> prefix(values.size());
	if (start >= prefix.size())
	{
		return prefix;
	}
	prefix[start] = values[start];
	for (int i = start+1; i < values.size(); i++)
	{
		if (i % 2 == start % 2)
		{
			prefix[i] = prefix[i - 1] + values[i];
		}
		else
		{
			prefix[i] = prefix[i - 1];
		}
	}
	return prefix;
}

vector<ll> rand_vec(int n)
{
	vector<ll> v(n);
	for (int i = 0; i < n; i++)
	{
		v[i] = (rand() % 2 == 0) ? rand() % 10 : -(rand() % 10);
	}
	return v;
}

pair<ll, ll> solve(const vector<ll>& A, const vector<ll>& B, int l, int r, ll x0, ll y0)
{
	auto prefix_A_even = make_prefixes(A, 0);
	auto prefix_A_odd = make_prefixes(A, 1);
	auto prefix_B_even = make_prefixes(B, 0);
	auto prefix_B_odd = make_prefixes(B, 1);

	ll x = compute_coordinate(prefix_A_even, prefix_A_odd, l , r , x0);
	ll y = compute_coordinate(prefix_B_even, prefix_B_odd, l , r, y0);
	return { x,y };

}

void test()
{
	int n = rand()%1000 + 1;
	auto A = rand_vec(n);
	auto B = rand_vec(n);
	int q = rand() % 100 + 1;
	for (size_t i = 0; i < q; i++)
	{
		int x0 = (rand() % 2 == 0) ? rand() % 10 : -(rand() % 10);
		int y0 = (rand() % 2 == 0) ? rand() % 10 : -(rand() % 10);
		int l = rand() % n;
		int r = rand() % n;
		auto s1 = brutus(A, B, min(l, r), max(l, r), x0, y0);
		auto s2 = solve(A, B, min(l, r), max(l, r), x0, y0);
		if (s1.first != s2.first || s1.second != s2.second)
		{
			cout << "WA\n";
		}
		else
		{
			cout << "OK\n";
		}
	}
	
}

int main()
{
	/*srand(time(0));
	for (size_t i = 0; i < 100000; i++)
	{
		test();
	}*/
	ios::sync_with_stdio(false);
	cin.tie(0);
	int n; cin >> n;
	vector<ll> A(n), B(n);
	for (int i = 0; i < n; i++)
	{
		cin >> A[i] >> B[i];
	}
	auto prefix_A_even = make_prefixes(A, 0);
	auto prefix_A_odd = make_prefixes(A, 1);
	auto prefix_B_even = make_prefixes(B, 0);
	auto prefix_B_odd = make_prefixes(B, 1);

	

	int q; cin >> q;
	for (int i = 0; i < n; i++)
	{
		ll x0, y0;
		int l, r;
		cin >> x0 >> y0 >> l >> r;
		auto sol = brutus(A, B, l-1, r-1, x0, y0);
		ll x = compute_coordinate(prefix_A_even, prefix_A_odd, l - 1, r - 1, x0);
		ll y = compute_coordinate(prefix_B_even, prefix_B_odd, l - 1, r - 1, y0);
		cout << sol.first << " " << sol.second << "\n";
	}

	return 0;
}